
//
// FixEncodingTests.cs
//
// Author:
//    Tomas Restrepo (tomasr@mvps.org)
//

using System;
using System.Collections.Generic;
using System.IO;
using System.Text;

using Microsoft.BizTalk.Message.Interop;
using Microsoft.BizTalk.Component.Interop;
using Microsoft.BizTalk.Component;
using Microsoft.BizTalk.DefaultPipelines;
using XMLNORM;

using NUnit.Framework;

using Winterdom.BizTalk.PipelineTesting;

namespace Winterdom.BizTalk.Samples.FixEncoding.Tests
{
   [TestFixture]
   public class FixEncodingTests
   {
      /// <summary>
      /// Tests the encoding is set correctly
      /// </summary>
      [Test]
      public void Test_SetEncoding()
      {
         ReceivePipelineWrapper pipeline = PipelineFactory.CreateEmptyReceivePipeline();
         FixEncodingComponent component = new FixEncodingComponent();
         component.Encoding = Encoding.UTF32;
         pipeline.AddComponent(component, PipelineStage.Decode);

         IBaseMessage inputMessage = MessageHelper.CreateFromString("hello!");

         MessageCollection outputMessages = pipeline.Execute(inputMessage);
         Assert.IsNotNull(outputMessages);
         Assert.IsTrue(outputMessages.Count > 0);
         Assert.AreEqual("utf-32", outputMessages[0].BodyPart.Charset);
      }

      [Test]
      public void Test_SetTargetCharset()
      {
         SendPipelineWrapper pipeline = PipelineFactory.CreateEmptySendPipeline();
         SetEncodingComponent component = new SetEncodingComponent();
         component.Encoding = Encoding.UTF32;
         pipeline.AddComponent(component, PipelineStage.PreAssemble);

         IBaseMessage inputMessage = MessageHelper.CreateFromString("<message>hello!</message>");
         MessageCollection inputMessages = new MessageCollection();
         inputMessages.Add(inputMessage);

         IBaseMessage outputMessage = pipeline.Execute(inputMessages);
         Assert.IsNotNull(outputMessage);

         TargetCharset targetCharset = new TargetCharset();
         string charset = (string)outputMessage.Context.Read(
            targetCharset.Name.Name, targetCharset.Name.Namespace
         );
         Assert.AreEqual("utf-32", charset);
      }
   } // class FixEncodingTests

} // namespace Winterdom.BizTalk.Samples.FixEncoding.Tests
